==> nexxT-1.0.4-cp37-abi3-win_amd64.whl: nexxT/core/qrc_resources.py <==
# Resource object code (Python 3)
# Created by: object code
# Created by: The Resource Compiler for Qt version 6.4.0
# WARNING! All changes made in this file will be lost!

from PySide6 import QtCore

qt_resource_data = b"\
\x00\x00\x08d\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2223\
.818361mm\x22\x0a   he\
ight=\x2223.016552m\
m\x22\x0a   viewBox=\x220\
 0 23.818361 23.\
016552\x22\x0a   versi\
on=\x221.1\x22\x0a   id=\x22\
svg8\x22\x0a   inkscap\
e:version=\x220.92.\
4 (5da689c313, 2\
019-01-14)\x22\x0a   s\
odipodi:docname=\
\x22media-record.sv\
g\x22>\x0a  <defs\x0a    \
 id=\x22defs2\x22 />\x0a \
 <sodipodi:named\
view\x0a     id=\x22ba\
se\x22\x0a     pagecol\
or=\x22#ffffff\x22\x0a   \
  bordercolor=\x22#\
666666\x22\x0a     bor\
deropacity=\x221.0\x22\
\x0a     inkscape:p\
ageopacity=\x220.0\x22\
\x0a     inkscape:p\
ageshadow=\x222\x22\x0a  \
   inkscape:zoom\
=\x221.979899\x22\x0a    \
 inkscape:cx=\x2286\
.156501\x22\x0a     in\
kscape:cy=\x2240.84\
2299\x22\x0a     inksc\
ape:document-uni\
ts=\x22mm\x22\x0a     ink\
scape:current-la\
yer=\x22layer1\x22\x0a   \
  showgrid=\x22fals\
e\x22\x0a     inkscape\
:window-width=\x221\
920\x22\x0a     inksca\
pe:window-height\
=\x22995\x22\x0a     inks\
cape:window-x=\x220\
\x22\x0a     inkscape:\
window-y=\x220\x22\x0a   \
  inkscape:windo\
w-maximized=\x221\x22 \
/>\x0a  <metadata\x0a \
    id=\x22metadata\
5\x22>\x0a    <rdf:RDF\
>\x0a      <cc:Work\
\x0a         rdf:ab\
out=\x22\x22>\x0a        \
<dc:format>image\
/svg+xml</dc:for\
mat>\x0a        <dc\
:type\x0a          \
 rdf:resource=\x22h\
ttp://purl.org/d\
c/dcmitype/Still\
Image\x22 />\x0a      \
  <dc:title></dc\
:title>\x0a      </\
cc:Work>\x0a    </r\
df:RDF>\x0a  </meta\
data>\x0a  <g\x0a     \
inkscape:label=\x22\
Layer 1\x22\x0a     in\
kscape:groupmode\
=\x22layer\x22\x0a     id\
=\x22layer1\x22\x0a     t\
ransform=\x22transl\
ate(-20.430431,-\
27.309361)\x22>\x0a   \
 <circle\x0a       \
style=\x22fill:#ff0\
000;stroke:#0000\
00;stroke-width:\
0.82299995;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-opac\
ity:1\x22\x0a       id\
=\x22path817\x22\x0a     \
  cx=\x2232.339611\x22\
\x0a       cy=\x2238.5\
50369\x22\x0a       r=\
\x227.2162771\x22 />\x0a \
   <rect\x0a       \
style=\x22fill:none\
;stroke:none;str\
oke-width:0.5243\
5654;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-opacity:1\x22\
\x0a       id=\x22rect\
819\x22\x0a       widt\
h=\x2223.818361\x22\x0a  \
     height=\x2223.\
016552\x22\x0a       x\
=\x2220.430431\x22\x0a   \
    y=\x2227.309361\
\x22 />\x0a  </g>\x0a</sv\
g>\x0a\
\x00\x00\x05\xf5\
\x00\
\x00\x1f#x\xda\xedY\xdb\x8e\xdb6\x10}\xdf\xafP\
\xb5\x0fI\xd0P\x22u\x97\xd6v\xd06\x08\x10\xa0\xe8\
C\xbbE\x9f\xb9\x12m\x13\x91D\x83\xa2\xd7v\xbe\xbe\
C\xeaf\xf9Rl\xb1H\x11\x146\xb0Xk\xe6p\
\x863<<\x22wg\x1f\xf6Ui=3\xd9pQ\
\xcfm\xe2`\xdbbu.\x0a^\xaf\xe6\xf6\x9f\x8f\x9f\
Pb[\x8d\xa2uAKQ\xb3\xb9]\x0b\xfb\xc3\xe2\
n\xf6\x03B\xd6/\x92Q\xc5\x0ak\xc7\xd5\xda\xfa\x5c\
\x7fir\xbaa\xd6\xdb\xb5R\x9b\xccuw\xbb\x9d\xc3\
;\xa3#\xe4\xca}g!\xb4\xb8\xbb\x9b5\xcf\xab;\
\xcb\xb2 o\xdddE>\xb7\xbb\x01\x9b\xad,\x0d\xb0\
\xc8]V\xb2\x8a\xd5\xaaq\x89C\x5c{\x84\xe7#<\
\xd7\xd9\xf93\xcbEU\x89\xba1#\xeb\xe6\xfe\x08,\
\x8b\xe5\x80\xd6\xb3\xd9\xf9\x06D\xd24u\xb1\xe7z\x1e\
\x02\x04j\x0e\xb5\xa2{4\x1d\x0as\xbc4\xd4\xc3\x18\
\xbb\xe0\x1b\x91/Ce\x0d4t\x03?\x03\xbc78\
\x8d\xd8\xca\x9c-a\x1csj\xa6\xdc\x8f\x8f\x1f\x07'\
\xc2N\xa1\x8a\xa30}?'Y'M\xaei\xc5\x9a\
\x0d\xcdY\xe3\xf6v3~\xc7\x0b\xb5\x9e\xdb^\xe0\xf8\
\xd8'\xa9WU\xc6\xbcf|\xb5V\xe7\xf6g\xcev\
?\x8b\xfd\xdc\xc6\x16\xb6\x06\xe7\xf8\xad\x05\x8d\xac!\xc6\
\xc0\x8b\xb9\x0du'\xedC\x97>\x1b`\xd8I='\
\xb0\xde\x86\x05\x8d\x924\xf7\x89\xff\xde\xf20I\x11&\
\x88\x04\xef\xcc\xa8\xbe\xf4\xac\x10\xb9\xae\x05\x08\xc7\xf6\xfb\
G\xa7o\xe7\x10\x95\xed7B*\xb4\xe4%kq\xee\
ZT\xcc\xddqV\xb0\x8a\xd6n\xc1\x9eY)6\x9a\
E\xae\x09\xe1\xee\x84\xfcbZ\xd3>\xa3(p6\xf5\
\xe5\xa8\xfbb\x03K\x15EN\x92\x00Y\xd2\x8b\x98\xc3\
\x09f\x01\xa0Y\xc1\x96\x8d\x06\xb7\xbd\xd0O\x9em\xb9\
\xc65T\xa6\xa7[\xe8\x06\x8f\xc0'\xda\xb4\xcbdY\
\x1b\xba\x02J\x97B\xce\xed\xfb\xa5\xf9t\x8e'!\x0b\
&{Wd>\x13\x97\x80\xda\xb8:\xb4\x9b\xb8\x8b\xdd\
\xcfYG\x1d\xfc\xf8\xb2\xbfY\xd3B\xec\x80\x0b\xa7\xce\
\xafBTzT\x10za\x90\xf8\xc1\xa9?\x07\x9e \
p8$\xc1Q|\xe6\x85\x8c^\x1c8)\xf6\xe3\xf0\
\xd4\x09\xab\xbc\xd5K\x84\xb65W\xb0\x99:\xfa\x1d\x0f\
\xdfJ\xa9\x01%=0(\xdc\xfc\x22\x1d\xa8Y\x8b\xdd\
J\xea\x06.i9tp\x18\xba\xe35\x14\x84:\xea\
\x03k\xf1\x15D\xbf\x0b\xd24\xbc\x82\xd0;\xe1\x8a\xeb\
p\xddU\xd1=\xaf\xf8W\x06\x13$\x86\x1f@\x83\x01\
\xa3'\xde\x0e\xb3,u\xd0{z\x7f\xd06\xbb7\xea\
\xba\xb4!\x08Co0\x0a\xc9W\xbc6\x0d\xf7\x1c\x1c\
{8 '>\x98\x0f\x22Q\xec\xf8\x91\x1f\xa5=\xf9\
\xdcs\xf6\x19{\xc5\x14-\xa8\xa2#\x15{K\xd8O\
\x1842\xfb\xfd\xe3\xa7E\x97e\x96\xe7\xd9_\xb0\x93\
\xfa\xa4\x96\xa5\x01\xf4Il\xa1\x81\xf6b0\xcf\x8a<\
\x03U\xab\xa8Z\xf0\x0a\xd8\xa5\x05\xf1GP\xb1\x99;\
:&`\xdd\x831h\x1bV\xb2V\x1e/\xbe#\x8a\
\xbc\xe2z\x90\xfb\x87\xe2e\xf9Y'\xe9\xca=\x0a\xca\
U\xc9\x16&g\xfb\xb5\xaf\xc2\xed\xca\xe8\x8at\x8f\xaa\
\x9c\xb9}\x0f\xcc\xd3\xeadmK\xfa\xc4\xca\xb9\xfd\xab\
&\xa2ENW~%\xc5vS\x89\x82uT\xb5\xc7\
\xceN\xa8\xab$\xad\x1b\xdd\x86\xb9m\xbe\x96\xf0&}\
;\xae\xe9{Dp\xe8\xf8\xbeO\xbcw\xfdB\xe4\x5c\
\xe6\xe5\xd0\xa2F\x1dJH\x02\xfaWf\xf7y\xf2\xc4\
\x9e\xe2\x87FI\xf1\x85e\xf7\xd8|\xba\xc7\x96\xff\x19\
v\x12\xcf\xd7f\xd2\xdb\xa1{L\x96@P\x95\x05\xbd\
\xad\xa0\xa0\x02R\xd2CV\xc3\xdb\xbe\xb7v\xca\x91\x91\
\x0977T\xad\x03\x10\x84\xc1\xa8u \x0c\x1c\xcf\x03\
\xea\xc5\xa3U+\x12\x89\x9d \x09\xe2\x91\xc7R\x1b\x9d\
8\xc08\x8d\x86U\x9b)\xb6W=\x02\xb8\x92\x19\xb9\
\x86L\xc0\x03&\x9f\x99}Z\xbc\x00a0\xdfa\xba\
\xc0\xa8\xf2\xc1X\x9e\xa9\xe4\xb4V\x13\xdb\xcel\xf1\x89\
\x09\x8ac*_Om\xb0[3\x82\x9d0\x81\xde\xfb\
\xd8\xdb\xec\x1fJ^\xb3N!2\xe2xa\x0b\x5c\xd2\
\x8a\x97\x87\xec\xcdO\x90\xaa\xb4~.i\xfe\xe5\xcd\x03\
\xeai\x80\xda`\x1b\x96\xf3%\xcf\xe1\x98\x22\xea\x09\xf4\
\xbd\xf5\x9bI\xfaf2aT\xf2\x15U[(\xf6R\
9\x08\x02_v\xd4 \xa1\x92\xe7\x13\xdf\x92\x99H\xa8\
aJ\xc1Qn\x18\xa8;\x8c($\xaa38\xd5I\
\xf5P\x02\x80I\xa4;\x0d\xb8\x0cC\xc5\xf0\xa2,\xa6\
\x06\xc9u\x10\xa4y\x9d\x95\x12\xa9\xa7.N\x9d\xaf\x85\
\xec\x02\xb5L\xa44\x8055\x0f#mzb\x1es\
\xaag\xa5\x17\x05\xba\xd9#3\xb4\xb6\x11\x0f\x8e\x14$\
\x0e\xd2\xc1\x0a$\x0a\xb1CbL\x82x\xc2B=\x11\
x1\x05\x83\xf1hgI\xa1\xcc\xb6J1l\xa2\x99\
\x82\x92\xeaQa\x06E\x94BsI/\xb3=zM\
h=\x00b{G\xf6\xcb\xb3\xbb2\xbf\xff\x96\xa8\xff\
/^\xfe{\xce]#\xd6\xa2\x9e\xb9f)\xe1=\xa0\
C\xdc\xb4\xe6\xa65\xe3n\x86]\x1b\xc5q\x1a\xf9\xc7\
RC\x88\xe7\xa4Q\xe8\x91KR\x93\xbcFK\xa2\xa9\
\x96\x9cg\xbf\x92\xff&%\xdf\x85\x94\xb0\x9b\x94\xdc\xa4\
\xe4\x9a\x94\x10\x12\xc0\xf1\xdd\x8f\xc2c)Aa\x02'\
b\x12\x90\xe8\x82\x96\x1c\x8d\x1fn\x10\xc3\xf9\x05\xe5p\
\xef\x85\x1a\xcd\x8d\x9e$^\x12{/\x81\xeb\x13\x0a\x5c\
#\xd2 H\xc2\xe8\x1fNE\xaf;\x14\xf9x*d\
\xe7\xb5_\xab\xfe\xa6d\xdf\x85\x92\xedoJvS\xb2\
\xab\x17\xb00\x86s\x09\x09#o\x22e\xfa\xe2\x93\x10\
?\x09/IY\xf4Bm\x82\x8c>\x09\x83\x10\x87/\
\xd3>\x04k\x8e\xa3\x00\xa7\xe4\x92\x98\xc1\xb8\x12nx\
\xe4UZ\x16\x9c\x5c\xf0\xce\xab\xbfV\xffM\xccnb\
v\x13\xb3o&f\xdd\x1f2_\x7f\xc3\xf3\x03\xdfO\
&7<\xd8\xca\xbew\xfc\xb7\x9dQ\xca\x02\xfc\x1a1\
I\xceox\xd3\xecW\xf2\xdf\xa4\xe4\x1bK\xc9U\xf5\
x<W\x8f\x99\xbbZ\xdc\xcd\xf4\xff,\x16w\x7f\x03\
8y\x18\x8e\
"

qt_resource_name = b"\
\x00\x05\
\x00o\xa6S\
\x00i\
\x00c\x00o\x00n\x00s\
\x00\x10\
\x08\x12\xa3'\
\x00m\
\x00e\x00d\x00i\x00a\x00-\x00r\x00e\x00c\x00o\x00r\x00d\x00.\x00s\x00v\x00g\
\x00\x09\
\x0f\xd7\xb3G\
\x00n\
\x00e\x00x\x00x\x00T\x00.\x00s\x00v\x00g\
"

qt_resource_struct = b"\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x01\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x02\x00\x00\x00\x02\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x10\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\
\x00\x00\x01\x88\xbaK\x95\xc5\
\x00\x00\x006\x00\x01\x00\x00\x00\x01\x00\x00\x08h\
\x00\x00\x01\x88\xbaK\x95\xc7\
"

def qInitResources():
    QtCore.qRegisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)

def qCleanupResources():
    QtCore.qUnregisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)

qInitResources()

==> nexxT-1.0.5-cp37-abi3-win_amd64.whl: nexxT/core/qrc_resources.py <==
# Resource object code (Python 3)
# Created by: object code
# Created by: The Resource Compiler for Qt version 6.5.1
# WARNING! All changes made in this file will be lost!

from PySide6 import QtCore

qt_resource_data = b"\
\x00\x00\x08d\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2223\
.818361mm\x22\x0a   he\
ight=\x2223.016552m\
m\x22\x0a   viewBox=\x220\
 0 23.818361 23.\
016552\x22\x0a   versi\
on=\x221.1\x22\x0a   id=\x22\
svg8\x22\x0a   inkscap\
e:version=\x220.92.\
4 (5da689c313, 2\
019-01-14)\x22\x0a   s\
odipodi:docname=\
\x22media-record.sv\
g\x22>\x0a  <defs\x0a    \
 id=\x22defs2\x22 />\x0a \
 <sodipodi:named\
view\x0a     id=\x22ba\
se\x22\x0a     pagecol\
or=\x22#ffffff\x22\x0a   \
  bordercolor=\x22#\
666666\x22\x0a     bor\
deropacity=\x221.0\x22\
\x0a     inkscape:p\
ageopacity=\x220.0\x22\
\x0a     inkscape:p\
ageshadow=\x222\x22\x0a  \
   inkscape:zoom\
=\x221.979899\x22\x0a    \
 inkscape:cx=\x2286\
.156501\x22\x0a     in\
kscape:cy=\x2240.84\
2299\x22\x0a     inksc\
ape:document-uni\
ts=\x22mm\x22\x0a     ink\
scape:current-la\
yer=\x22layer1\x22\x0a   \
  showgrid=\x22fals\
e\x22\x0a     inkscape\
:window-width=\x221\
920\x22\x0a     inksca\
pe:window-height\
=\x22995\x22\x0a     inks\
cape:window-x=\x220\
\x22\x0a     inkscape:\
window-y=\x220\x22\x0a   \
  inkscape:windo\
w-maximized=\x221\x22 \
/>\x0a  <metadata\x0a \
    id=\x22metadata\
5\x22>\x0a    <rdf:RDF\
>\x0a      <cc:Work\
\x0a         rdf:ab\
out=\x22\x22>\x0a        \
<dc:format>image\
/svg+xml</dc:for\
mat>\x0a        <dc\
:type\x0a          \
 rdf:resource=\x22h\
ttp://purl.org/d\
c/dcmitype/Still\
Image\x22 />\x0a      \
  <dc:title></dc\
:title>\x0a      </\
cc:Work>\x0a    </r\
df:RDF>\x0a  </meta\
data>\x0a  <g\x0a     \
inkscape:label=\x22\
Layer 1\x22\x0a     in\
kscape:groupmode\
=\x22layer\x22\x0a     id\
=\x22layer1\x22\x0a     t\
ransform=\x22transl\
ate(-20.430431,-\
27.309361)\x22>\x0a   \
 <circle\x0a       \
style=\x22fill:#ff0\
000;stroke:#0000\
00;stroke-width:\
0.82299995;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-opac\
ity:1\x22\x0a       id\
=\x22path817\x22\x0a     \
  cx=\x2232.339611\x22\
\x0a       cy=\x2238.5\
50369\x22\x0a       r=\
\x227.2162771\x22 />\x0a \
   <rect\x0a       \
style=\x22fill:none\
;stroke:none;str\
oke-width:0.5243\
5654;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-opacity:1\x22\
\x0a       id=\x22rect\
819\x22\x0a       widt\
h=\x2223.818361\x22\x0a  \
     height=\x2223.\
016552\x22\x0a       x\
=\x2220.430431\x22\x0a   \
    y=\x2227.309361\
\x22 />\x0a  </g>\x0a</sv\
g>\x0a\
\x00\x00\x05\xf5\
\x00\
\x00\x1f#x\xda\xedY\xdb\x8e\xdb6\x10}\xdf\xafP\
\xb5\x0fI\xd0P\x22u\x97\xd6v\xd06\x08\x10\xa0\xe8\
C\xbbE\x9f\xb9\x12m\x13\x91D\x83\xa2\xd7v\xbe\xbe\
C\xeaf\xf9Rl\xb1H\x11\x146\xb0Xk\xe6p\
\x863<<\x22wg\x1f\xf6Ui=3\xd9pQ\
\xcfm\xe2`\xdbbu.\x0a^\xaf\xe6\xf6\x9f\x8f\x9f\
Pb[\x8d\xa2uAKQ\xb3\xb9]\x0b\xfb\xc3\xe2\
n\xf6\x03B\xd6/\x92Q\xc5\x0ak\xc7\xd5\xda\xfa\x5c\
\x7fir\xbaa\xd6\xdb\xb5R\x9b\xccuw\xbb\x9d\xc3\
;\xa3#\xe4\xca}g!\xb4\xb8\xbb\x9b5\xcf\xab;\
\xcb\xb2 o\xdddE>\xb7\xbb\x01\x9b\xad,\x0d\xb0\
\xc8]V\xb2\x8a\xd5\xaaq\x89C\x5c{\x84\xe7#<\
\xd7\xd9\xf93\xcbEU\x89\xba1#\xeb\xe6\xfe\x08,\
\x8b\xe5\x80\xd6\xb3\xd9\xf9\x06D\xd24u\xb1\xe7z\x1e\
\x02\x04j\x0e\xb5\xa2{4\x1d\x0as\xbc4\xd4\xc3\x18\
\xbb\xe0\x1b\x91/Ce\x0d4t\x03?\x03\xbc78\
\x8d\xd8\xca\x9c-a\x1csj\xa6\xdc\x8f\x8f\x1f\x07'\
\xc2N\xa1\x8a\xa30}?'Y'M\xaei\xc5\x9a\
\x0d\xcdY\xe3\xf6v3~\xc7\x0b\xb5\x9e\xdb^\xe0\xf8\
\xd8'\xa9WU\xc6\xbcf|\xb5V\xe7\xf6g\xcev\
?\x8b\xfd\xdc\xc6\x16\xb6\x06\xe7\xf8\xad\x05\x8d\xac!\xc6\
\xc0\x8b\xb9\x0du'\xedC\x97>\x1b`\xd8I='\
\xb0\xde\x86\x05\x8d\x924\xf7\x89\xff\xde\xf20I\x11&\
\x88\x04\xef\xcc\xa8\xbe\xf4\xac\x10\xb9\xae\x05\x08\xc7\xf6\xfb\
G\xa7o\xe7\x10\x95\xed7B*\xb4\xe4%kq\xee\
ZT\xcc\xddqV\xb0\x8a\xd6n\xc1\x9eY)6\x9a\
E\xae\x09\xe1\xee\x84\xfcbZ\xd3>\xa3(p6\xf5\
\xe5\xa8\xfbb\x03K\x15EN\x92\x00Y\xd2\x8b\x98\xc3\
\x09f\x01\xa0Y\xc1\x96\x8d\x06\xb7\xbd\xd0O\x9em\xb9\
\xc65T\xa6\xa7[\xe8\x06\x8f\xc0'\xda\xb4\xcbdY\
\x1b\xba\x02J\x97B\xce\xed\xfb\xa5\xf9t\x8e'!\x0b\
&{Wd>\x13\x97\x80\xda\xb8:\xb4\x9b\xb8\x8b\xdd\
\xcfYG\x1d\xfc\xf8\xb2\xbfY\xd3B\xec\x80\x0b\xa7\xce\
\xafBTzT\x10za\x90\xf8\xc1\xa9?\x07\x9e \
p8$\xc1Q|\xe6\x85\x8c^\x1c8)\xf6\xe3\xf0\
\xd4\x09\xab\xbc\xd5K\x84\xb65W\xb0\x99:\xfa\x1d\x0f\
\xdfJ\xa9\x01%=0(\xdc\xfc\x22\x1d\xa8Y\x8b\xdd\
J\xea\x06.i9tp\x18\xba\xe35\x14\x84:\xea\
\x03k\xf1\x15D\xbf\x0b\xd24\xbc\x82\xd0;\xe1\x8a\xeb\
p\xddU\xd1=\xaf\xf8W\x06\x13$\x86\x1f@\x83\x01\
\xa3'\xde\x0e\xb3,u\xd0{z\x7f\xd06\xbb7\xea\
\xba\xb4!\x08Co0\x0a\xc9W\xbc6\x0d\xf7\x1c\x1c\
{8 '>\x98\x0f\x22Q\xec\xf8\x91\x1f\xa5=\xf9\
\xdcs\xf6\x19{\xc5\x14-\xa8\xa2#\x15{K\xd8O\
\x1842\xfb\xfd\xe3\xa7E\x97e\x96\xe7\xd9_\xb0\x93\
\xfa\xa4\x96\xa5\x01\xf4Il\xa1\x81\xf6b0\xcf\x8a<\
\x03U\xab\xa8Z\xf0\x0a\xd8\xa5\x05\xf1GP\xb1\x99;\
:&`\xdd\x831h\x1bV\xb2V\x1e/\xbe#\x8a\
\xbc\xe2z\x90\xfb\x87\xe2e\xf9Y'\xe9\xca=\x0a\xca\
U\xc9\x16&g\xfb\xb5\xaf\xc2\xed\xca\xe8\x8at\x8f\xaa\
\x9c\xb9}\x0f\xcc\xd3\xeadmK\xfa\xc4\xca\xb9\xfd\xab\
&\xa2ENW~%\xc5vS\x89\x82uT\xb5\xc7\
\xceN\xa8\xab$\xad\x1b\xdd\x86\xb9m\xbe\x96\xf0&}\
;\xae\xe9{Dp\xe8\xf8\xbeO\xbcw\xfdB\xe4\x5c\
\xe6\xe5\xd0\xa2F\x1dJH\x02\xfaWf\xf7y\xf2\xc4\
\x9e\xe2\x87FI\xf1\x85e\xf7\xd8|\xba\xc7\x96\xff\x19\
v\x12\xcf\xd7f\xd2\xdb\xa1{L\x96@P\x95\x05\xbd\
\xad\xa0\xa0\x02R\xd2CV\xc3\xdb\xbe\xb7v\xca\x91\x91\
\x0977T\xad\x03\x10\x84\xc1\xa8u \x0c\x1c\xcf\x03\
\xea\xc5\xa3U+\x12\x89\x9d \x09\xe2\x91\xc7R\x1b\x9d\
8\xc08\x8d\x86U\x9b)\xb6W=\x02\xb8\x92\x19\xb9\
\x86L\xc0\x03&\x9f\x99}Z\xbc\x00a0\xdfa\xba\
\xc0\xa8\xf2\xc1X\x9e\xa9\xe4\xb4V\x13\xdb\xcel\xf1\x89\
\x09\x8ac*_Om\xb0[3\x82\x9d0\x81\xde\xfb\
\xd8\xdb\xec\x1fJ^\xb3N!2\xe2xa\x0b\x5c\xd2\
\x8a\x97\x87\xec\xcdO\x90\xaa\xb4~.i\xfe\xe5\xcd\x03\
\xeai\x80\xda`\x1b\x96\xf3%\xcf\xe1\x98\x22\xea\x09\xf4\
\xbd\xf5\x9bI\xfaf2aT\xf2\x15U[(\xf6R\
9\x08\x02_v\xd4 \xa1\x92\xe7\x13\xdf\x92\x99H\xa8\
aJ\xc1Qn\x18\xa8;\x8c($\xaa38\xd5I\
\xf5P\x02\x80I\xa4;\x0d\xb8\x0cC\xc5\xf0\xa2,\xa6\
\x06\xc9u\x10\xa4y\x9d\x95\x12\xa9\xa7.N\x9d\xaf\x85\
\xec\x02\xb5L\xa44\x8055\x0f#mzb\x1es\
\xaag\xa5\x17\x05\xba\xd9#3\xb4\xb6\x11\x0f\x8e\x14$\
\x0e\xd2\xc1\x0a$\x0a\xb1CbL\x82x\xc2B=\x11\
x1\x05\x83\xf1hgI\xa1\xcc\xb6J1l\xa2\x99\
\x82\x92\xeaQa\x06E\x94BsI/\xb3=zM\
h=\x00b{G\xf6\xcb\xb3\xbb2\xbf\xff\x96\xa8\xff\
/^\xfe{\xce]#\xd6\xa2\x9e\xb9f)\xe1=\xa0\
C\xdc\xb4\xe6\xa65\xe3n\x86]\x1b\xc5q\x1a\xf9\xc7\
RC\x88\xe7\xa4Q\xe8\x91KR\x93\xbcFK\xa2\xa9\
\x96\x9cg\xbf\x92\xff&%\xdf\x85\x94\xb0\x9b\x94\xdc\xa4\
\xe4\x9a\x94\x10\x12\xc0\xf1\xdd\x8f\xc2c)Aa\x02'\
b\x12\x90\xe8\x82\x96\x1c\x8d\x1fn\x10\xc3\xf9\x05\xe5p\
\xef\x85\x1a\xcd\x8d\x9e$^\x12{/\x81\xeb\x13\x0a\x5c\
#\xd2 H\xc2\xe8\x1fNE\xaf;\x14\xf9x*d\
\xe7\xb5_\xab\xfe\xa6d\xdf\x85\x92\xedoJvS\xb2\
\xab\x17\xb00\x86s\x09\x09#o\x22e\xfa\xe2\x93\x10\
?\x09/IY\xf4Bm\x82\x8c>\x09\x83\x10\x87/\
\xd3>\x04k\x8e\xa3\x00\xa7\xe4\x92\x98\xc1\xb8\x12nx\
\xe4UZ\x16\x9c\x5c\xf0\xce\xab\xbfV\xffM\xccnb\
v\x13\xb3o&f\xdd\x1f2_\x7f\xc3\xf3\x03\xdfO\
&7<\xd8\xca\xbew\xfc\xb7\x9dQ\xca\x02\xfc\x1a1\
I\xceox\xd3\xecW\xf2\xdf\xa4\xe4\x1bK\xc9U\xf5\
x<W\x8f\x99\xbbZ\xdc\xcd\xf4\xff,\x16w\x7f\x03\
8y\x18\x8e\
"

qt_resource_name = b"\
\x00\x05\
\x00o\xa6S\
\x00i\
\x00c\x00o\x00n\x00s\
\x00\x10\
\x08\x12\xa3'\
\x00m\
\x00e\x00d\x00i\x00a\x00-\x00r\x00e\x00c\x00o\x00r\x00d\x00.\x00s\x00v\x00g\
\x00\x09\
\x0f\xd7\xb3G\
\x00n\
\x00e\x00x\x00x\x00T\x00.\x00s\x00v\x00g\
"

qt_resource_struct = b"\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x01\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x02\x00\x00\x00\x02\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x10\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\
\x00\x00\x01\x89x?\x06\x17\
\x00\x00\x006\x00\x01\x00\x00\x00\x01\x00\x00\x08h\
\x00\x00\x01\x89x?\x06\x1f\
"

def qInitResources():
    QtCore.qRegisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)

def qCleanupResources():
    QtCore.qUnregisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)

qInitResources()
